@@ -3,6 +3,8 @@ from .apis.GraphAPI import GraphAPI
 from .apis.SalesForceAPI import SalesForceAPI
 from .fourmatters import virtual_network, virtual_machine
 from .logger.Logger import Logger
+from .http.HttpListener import HttpListener
+from . import gcp
 
 def format(data, table_type):
     formatter_types = {
