@@ -17,7 +17,7 @@ class Logger:
         time = datetime.now().strftime('%d-%m-%Y  %H:%M:%S:%f')
         log_msg = f'{time}\t{msg}\n'
         if self.file_pointer:
-            print(log_msg, file=self.file)  
+            print(log_msg.strip(), file=self.file)  
         else:
             with open(self.file_name, 'a') as outfile:
                 outfile.write(log_msg)
@@ -28,7 +28,10 @@ class Logger:
         else:
             self.log(f'executing {function}')
         try:
-            result = function(*parameters)
+            if type(parameters) == tuple:
+                result = function(*parameters)
+            if type(parameters) == dict:
+                result = function(**parameters)
             self.log(f'concluded {function}')
             return result
         except Exception as e:
